'use strict' // Strict mode
let PDFMerge = function (inputFiles, outputFile) {
  return new Promise((resolve, reject) => {
    // The error object
    let error = {
      'message': '',
      'code': 0
    }
    // Set outputFile to 'out.pdf' if it's not defined
    outputFile = outputFile || 'out.pdf'
    // Require child_process module to access spawn and execFile functions
    let {spawn} = require('child_process')
    // Require the default NodeJS path module
    let path = require('path')
    // initialize the array of arguments to be passed to pdfmerge.py
    let argumentsArray = [path.join(__dirname, '/pdfmerge.py')]
    // Push inputFiles to argumentsArray
    for (let i = 0; i < inputFiles.length; i++) {
      argumentsArray.push(inputFiles[i])
    }
    // Push '-o' to the argumentsArray, -o = output file
    argumentsArray.push('-o')
    // Push the specified output file to argumentsArray
    argumentsArray.push(outputFile)
    // Start pdfmerge python process :O
    let pdfmergepy = spawn('python', argumentsArray)
    // log stdout data to the console
    pdfmergepy.stdout.on('data', function (data) {
      console.log(data)
    })
    // If PyPDF2 is not found then throw error :-)
    // If 'path not found' on input then throw error ;-)
    pdfmergepy.stderr.on('data', function (data) {
      if (data.toString().match('PdfFileWriter')) {
        error.code = 1
        error.message = 'PyPDF2 not found. Install PyPDF2, run pip install PyPDF2>=1.21'
      }
      if (data.toString().match('AssertionError: ERROR: path not found:')) {
        error.code = 404 // Why 404? cuz why not
        error.message = 'Path not found. Please check input files.'
      }
    })
    // Success is code 0, Something other than 0 is not successful.
    pdfmergepy.on('close', function (code) {
      if (code === 0) {
        resolve('success')
      } else {
        reject(error)
      }
    })
    // If error, check for the code and log to console
    pdfmergepy.on('error', (err) => {
      if (err.code === 'ENOENT') {
        console.log('Please check if the PATH is correct!')
      }
    })
  })
}

module.exports = PDFMerge
